api.system.services.v1.test_helpers.status package — Argus-Toolbelt 1.0 documentation

# api.system.services.v1.test_helpers.status package

## Submodules

## api.system.services.v1.test_helpers.status.get_service_status module

`api.system.services.v1.test_helpers.status.get_service_status.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/services/v1/status, respond with HTTP 403

`api.system.services.v1.test_helpers.status.get_service_status.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/services/v1/status, respond with HTTP 404

`api.system.services.v1.test_helpers.status.get_service_status.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/services/v1/status, respond with HTTP 200

`api.system.services.v1.test_helpers.status.get_service_status.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/services/v1/status, respond with HTTP 401

## Module contents